% This file computes trim conditions for the 4-state nonlinear and
% polynomial models at a wide range of airspeeds. The nonlinear 
% model uses the raw aero look-up tables, trig functions, and 1/V.  The 
% polynomial model uses polynomial fits for these nonlinearities.
%

% Create Polynomial Model
gtmlongpoly;

% Set range of trim air speeds (m/sec)
Vtrim = 30:5:60;
Ntrim = length(Vtrim);

% Compute trim conditions
xtn = zeros(4,Ntrim);   utn = zeros(2,Ntrim);
xtp = zeros(4,Ntrim);   utp = zeros(2,Ntrim);
opts=optimset('Display','off');
fprintf('Solving at Vtrim (m/sec) =     \t');
for i1=1:Ntrim
    % Display current trim speed
    fprintf('\b\b\b\b%4.1f',Vtrim(i1));
    
    % Compute level-flight trim condition for poly model
    if i1==1
        x0 = [45; 0.05;0;-0.05];
        u0 = [16;3*d2r];
    else
        x0 = xtp(:,i1-1);
        u0 = utp(:,i1-1);
    end    
    [xt,ut,ft,ht,flg]=ptrim(flong,x,u,x0,u0,[V-Vtrim(i1); alpha-theta],opts);
    if flg~=1
        warning(['Trim values at Vtrim = ' num2str(Vtrim(i1)) ' may not be valid']);
    end
    xtp(:,i1) = xt;
    utp(:,i1) = ut;
    
    % Compute level-flight trim condition for nonlinear model
    if i1==1
        x0 = [45; 0.05;0;-0.05];
        u0 = [16;3*d2r];
    else
        x0 = xtn(:,i1-1);
        u0 = utn(:,i1-1);
    end    
    fhn = @(z) [gtmlongnl([],z(5:6),z(1:4),Aero); z(1)-Vtrim(i1); z(2)-z(4)];
    [z,ft,flg] = fsolve(fhn,[x0;u0],opts);
    if flg~=1
        warning(['Trim values at Vtrim = ' num2str(Vtrim(i1)) ' may not be valid']);
    end
    xtn(:,i1) = z(1:4); 
    utn(:,i1) = z(5:6); 
end
fprintf('\n');

% Plot trim conditions versus trim speed
figure;
subplot(321);
plot(Vtrim,xtn(1,:),'sb',Vtrim,xtp(1,:),'rx');
xlabel('TAS (m/sec)'); 
ylabel('TAS (m/sec)');
legend('NL','Poly',0);

subplot(322);
plot(Vtrim,xtn(2,:)*r2d,'sb',Vtrim,xtp(2,:)*r2d,'rx'); 
xlabel('TAS (m/sec)'); 
ylabel('alpha (deg)');

subplot(323);
plot(Vtrim,xtn(3,:)*r2d,'sb',Vtrim,xtp(3,:)*r2d,'rx'); 
xlabel('TAS (m/sec)'); 
ylabel('q (deg/sec)');
axis([Vtrim(1) Vtrim(end) -1e-5 1e-5])

subplot(324);
plot(Vtrim,xtn(4,:)*r2d,'sb',Vtrim,xtp(4,:)*r2d,'rx'); 
xlabel('TAS (m/sec)'); 
ylabel('theta (deg)');

% Plot Inputs
subplot(325);
plot(Vtrim,utn(1,:),'sb',Vtrim,utp(1,:),'rx'); 
xlabel('TAS (m/sec)'); ylabel('throttle (percent)');

subplot(326);
plot(Vtrim,utn(2,:),'sb',Vtrim,utp(2,:),'rx'); 
xlabel('TAS (m/sec)'); ylabel('elev (rad)');

